@@ -34,7 +34,7 @@
 <dl>
 <?cs each:item = Thread ?>
 <dt><?cs var:html_escape(item.resno) ?>
-OF<b><?cs if:item.mail ?><a href="<?cs var:html_escape(item.mail) ?>"><?cs var:item.name ?></a><?cs else ?><?cs var:item.name ?><?cs /if ?></b>F<?cs var:html_escape(item.date) ?></dt><dd id="r<?cs var:html_escape(item.resno) ?>"><?cs var:item.text ?><br><br></dd>
+OF<b><?cs if:item.mail ?><a href="<?cs var:html_escape(item.mail) ?>"><?cs var:item.name ?></a><?cs else ?><?cs var:item.name ?><?cs /if ?></b>F<?cs var:item.date ?></dt><dd id="r<?cs var:html_escape(item.resno) ?>"><?cs var:item.text ?><br><br></dd>
 <?cs /each ?>
 </dl>
 
