@@ -5,10 +5,7 @@
 <meta http-equiv="Content-Script-Type" content="text/javascript">
 <meta http-equiv="Content-Style-Type" content="text/css">
 <meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
-<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js" charset="UTF-8"></script>
-<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js" charset="UTF-8"></script>
-<script src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js"
-charset="UTF-8"></script>
+<script src="<?cs var:html_escape(StaticURI) ?>/js/img0ch.js" charset="UTF-8"></script>
 <script type="text/javascript">
 //<!--
 var app = Img0ch.App;
@@ -18,7 +15,7 @@ app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
 app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
 app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
 function linkAsPost(option) {
-    var formElement = jQuery("form#virtualThreadForm");
+    var formElement = jQuery("#virtualThreadForm");
     formElement.append("<input type='hidden' name='option' value='" + option + "'>");
     var newFormElement = jQuery("<form>");
     newFormElement.attr({ "method": "POST", "action": formElement.attr("action") });
@@ -44,7 +41,7 @@ function addFormLinks( props, dist ) {
     for ( var i in props ) {
         var a = jQuery("<a>").attr( "href", "#" + i );
         a.click(function(){
-            var formElement = jQuery("form#virtualThreadForm");
+            var formElement = jQuery("#virtualThreadForm");
             /#(.+)$/.test(this.href);
             formElement.append("<input type='hidden' name='mode' value='" + RegExp.$1 + "'>");
             linkAsPost();
@@ -270,7 +267,7 @@ p̃XbhɃ[UƃpX[h݂A<br>
 <dl>
 <font color="<?cs var:html_escape(BBS_SUBJECT_COLOR) ?>" size="+1"> <?cs var:Subject ?></font><br><br>
 
-<?cs each:item = Thread ?><dt><input type="checkbox" name="resno" value="<?cs var:html_escape(item.resno) ?>"> <?cs var:html_escape(item.resno) ?> OF<b><?cs if:item.mail ?><a href="mailto:<?cs var:html_escape(item.mail) ?>"><?cs var:item.name ?></a><?cs else ?><font color="<?cs var:html_escape(BBS_NAME_COLOR) ?>"><?cs var:item.name ?></font><?cs /if ?></b>F<?cs var:html_escape(item.date) ?> <a href="#virtualThreadForm"></a></dt><dd><?cs var:item.text ?><br><br></dd>
+<?cs each:item = Thread ?><dt><input type="checkbox" name="resno" value="<?cs var:html_escape(item.resno) ?>"> <?cs var:html_escape(item.resno) ?> OF<b><?cs if:item.mail ?><a href="mailto:<?cs var:html_escape(item.mail) ?>"><?cs var:item.name ?></a><?cs else ?><font color="<?cs var:html_escape(BBS_NAME_COLOR) ?>"><?cs var:item.name ?></font><?cs /if ?></b>F<?cs var:item.date ?> <a href="#virtualThreadForm"></a></dt><dd><?cs var:item.text ?><br><br></dd>
 <?cs /each ?>
 </dl>
 
