@@ -1,8 +1,10 @@
 <div id="sidebar">
   <div>
     <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">スレッド整理</a><br />
+    <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_special_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">特殊スレッド整理</a><br />
     <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_pooled_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">プールスレッド整理</a><br />
     <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_archived_threads&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">過去ログ整理</a><br />
+    <a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=rewrite_form&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">スレッドの本文置換</a><br />
   </div>
   <div>
     <a href="<?cs var:html_escape(ZerominScript) ?>?class=pool&amp;method=auto_form&amp;item=<?cs var:html_escape(Item) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">自動プーリング</a><br />
