@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: MailPost.pm 902 2007-07-15 14:12:41Z hikarin $
+# $Id: MailPost.pm 1645 2008-02-06 15:40:18Z hikarin $
 #
 
 package Img0ch::App::MailPost;
@@ -22,11 +22,13 @@ package Img0ch::App::MailPost;
 use strict;
 use base qw(Img0ch::App::BBS);
 use Email::MIME qw();
+use Email::Send qw();
 
 sub new {
     my ( $iClass, $iKernel, @args ) = @_;
     my $iApp = $iClass->SUPER::new( $iKernel, @args );
-    $iApp->{__from} = undef;
+    $iApp->{__encoding} = undef;
+    $iApp->{__from}     = undef;
     $iApp->{_request}
         = Img0ch::App::MailPost::Request->new( Img0ch::Request->new(@args) );
     return $iApp;
@@ -34,7 +36,7 @@ sub new {
 
 sub run {
     my ($iApp) = @_;
-    my $iConfig = $iApp->{_config};
+    my $iConfig = $iApp->config();
     $iConfig->get('Maintenance')
         and die 'img0ch MAINTENANCE: Please try again later.', "\n";
 
@@ -62,7 +64,7 @@ sub run {
         $fetch++;
     }
     else {
-        $iApp->{_request}->init( $iApp->{_config} );
+        $iApp->{_request}->init($iConfig);
     }
 
     $iApp->redirect_success($fetch);
@@ -72,22 +74,18 @@ sub run {
 sub redirect_success {
     my ( $iApp, $fetch ) = @_;
     my $iBBS     = $iApp->bbs();
-    my $iConfig  = $iApp->{_config};
+    my $iConfig  = $iApp->config();
     my $iRequest = $iApp->{_request};
 
     if ( !$iBBS ) {
-        require Img0ch::BBS;
         my $iKernel = $iApp->kernel();
         my @path = split '/', $iRequest->path_info();
         $path[1] =~ /\A([\w\-]+)\z/xms;
         $iBBS = Img0ch::BBS->new( $iKernel, { bbs => $1 } );
     }
 
-    require Img0ch::Metadata;
-    require Img0ch::Template;
-    my $iMeta     = Img0ch::Metadata->new($iBBS);
-    my $iTemplate = Img0ch::Template->new(
-        $iBBS,
+    my $iMeta     = $iBBS->get_metadata_instance();
+    my $iTemplate = $iBBS->get_template_instance(
         {   file    => 'mobile',
             request => $iRequest,
             setting => $iApp->setting(),
@@ -110,16 +108,17 @@ sub redirect_success {
 
 sub get_mail_via_pop3 {
     my ( $iApp, $mail_rec ) = @_;
-    my $iConfig = $iApp->{_config};
+    my $iConfig = $iApp->config();
     my $iKernel = $iApp->kernel();
 
-    require Mail::POP3Client;
+    defined $Mail::POP3Client::VERSION or require Mail::POP3Client;
     my $pop3 = Mail::POP3Client->new(
         HOST =>
             ( $iConfig->get('pop3.server') || $iConfig->get('POP3Server') ),
-        PORT => ( $iConfig->get('pop3.port') || 110 ),
+        PORT => ( $iConfig->get_int('pop3.port') || 110 ),
         USESSL => ( $iConfig->get('pop3.ssl') ? 1 : 0 ),
-        TIMEOUT => 5,
+        TIMEOUT   => ( $iConfig->get_int('pop3.timeout') || 5 ),
+        AUTH_MODE => ( $iConfig->get('pop3.auth')        || 'BEST' ),
     );
     $pop3->User( $iConfig->get('pop3.user') || $iConfig->get('POP3User') );
     $pop3->Pass( $iConfig->get('pop3.pass') || $iConfig->get('POP3Pass') );
@@ -144,7 +143,7 @@ sub get_mail_via_pop3 {
 
 sub get_mail_via_imap {
     my ( $iApp, $mail_rec ) = @_;
-    my $iConfig = $iApp->{_config};
+    my $iConfig = $iApp->config();
     my $iKernel = $iApp->kernel();
     my $imap;
 
@@ -188,12 +187,10 @@ sub send_error_mail {
     my $from    = $iConfig->get('MailRawAddress');
     my $to      = $iApp->{__from};
 
-    require Unicode::Japanese;
     $message =~ s{<br\s?/?>}{\n}gxms;
-    my $message_jis = Unicode::Japanese->new( $message, 'auto' )->jis();
+    my $message_jis = $iKernel->get_encoded_str( $message, 'jis' );
     $iApp->{_request}->init($iConfig);
 
-    require Email::Send;
     my $sender;
     if ( my $sendmail = $iConfig->get('SendmailPath') ) {
         $sender = Email::Send->new( { mailer => 'Sendmail' } );
@@ -216,7 +213,6 @@ sub send_error_mail {
         );
     }
 
-    require Img0ch::Template;
     my $iTemplate
         = Img0ch::Template->new( $iKernel, { file => 'mobile_error_mail' } );
     $iTemplate->param(
@@ -232,15 +228,14 @@ sub send_error_mail {
 
 sub set_parameters_from_mail {
     my ( $iApp, $mail_rec ) = @_;
-    my $iConfig  = $iApp->{_config};
     my $iKernel  = $iApp->kernel();
     my $iRequest = $iApp->request();
+    my $iConfig  = $iKernel->get_config();
 
     map {tr/\r\n//d} @$mail_rec;    ## no critic
     my $mime = Email::MIME->new( join "\r\n", @$mail_rec );
     $iApp->_get_host( $iConfig, $mime ) or return 0;
 
-    require Unicode::Japanese;
     my $found = 0;
     for my $part ( $mime->parts() ) {
         if ( my $fn = $part->filename() ) {
@@ -248,16 +243,18 @@ sub set_parameters_from_mail {
             if ( $cte =~ s/\s+//gxms ) {
                 $part->header_set( 'Content-Transfer-Encoding', $cte );
             }
-            require File::Temp;
+            defined $File::Temp::VERSION or require File::Temp;
             my ( $fh, $temp ) = File::Temp::tempfile( UNLINK => 1 );
             binmode $fh;
-            print {$fh} $part->body();
-            close $fh;
+            print {$fh} $part->body() or $iKernel->throw_exception($temp);
+            close $fh or $iKernel->throw_exception($temp);
             $iRequest->upload_internal( $temp, $fn );
             $found++;
         }
         else {
-            $iApp->_parse_body( \$part->body() ) or return 0;
+            my $body_encoding = Email::MIME::ContentType::parse_content_type(
+                $part->content_type() )->{attributes}->{charset};
+            $iApp->_parse_body( \$part->body(), $body_encoding ) or return 0;
         }
     }
     if ( !$found ) {
@@ -265,19 +262,22 @@ sub set_parameters_from_mail {
         return 0;
     }
 
-    my $subject
-        = Unicode::Japanese->new( $mime->header('Subject'), 'auto' )->sjis();
+    my $header_encoding = $iConfig->get('pop3.header_encoding') || 'utf8';
+    my $subject = $iKernel->get_encoded_str( $mime->header('Subject'),
+        undef, $header_encoding );
     $subject =~ s/\A\s+//xms;
     $subject =~ s/\s+\z//xms;
     $subject =~ s/(?:\r\n)+//gxms;
     $subject =~ s/\n+//gxms;
     _nonl($subject);
-    if ( $subject =~ /(.*?)<>(.*)/xms ) {
-        my ( $name, $mail ) = ( $1, $2 );
-        $name =~ s/\s+\z//xms;
-        $mail =~ s/\A\s+//xms;
+
+    if ( index( $subject, '<>' ) >= 0 ) {
+        $subject =~ s/\A\s*//xms;
+        $subject =~ s/\s*\z//xms;
+        my ( $name, $mail, $rmkey ) = split '<>', $subject, 3;
         $iRequest->set_param_internal( 'FROM', $name );
-        $iRequest->set_param_internal( 'mail', $mail );
+        $iRequest->set_param_internal( 'mail', ($mail || '') );
+        $iRequest->set_param_internal( 'pass', ($rmkey || '') )
     }
     else {
         $iRequest->set_param_internal( 'FROM', $subject );
@@ -295,9 +295,9 @@ sub set_parameters_from_mail {
 }
 
 sub _parse_body {
-    my ( $iApp, $body ) = @_;
+    my ( $iApp, $body, $encoding ) = @_;
     my $iRequest = $iApp->request();
-    my ( $bbs, $key, $text ) = split '<>', $$body;
+    my ( $bbs, $key, $text ) = split '<>', $$body, 3;
 
     $bbs ||= '';
     $key ||= '';
@@ -305,7 +305,9 @@ sub _parse_body {
         $iRequest->set_param_internal( 'bbs', $1 );
         if ( $key =~ /\A(\d{9,10})\z/xms ) {
             $iRequest->set_param_internal( 'key', $1 );
-            $text = Unicode::Japanese->new( $text, 'auto' )->sjis();
+            $encoding ||= $iApp->config()->get('pop3.body_encoding');
+            $text
+                = $iApp->kernel()->get_encoded_str( $text, undef, $encoding );
             _nonl($text);
             $text =~ s/\r\n/\n/gxms;
             $text =~ s/\n\n/\n/gxms;
@@ -353,7 +355,6 @@ sub _get_host {
     $iApp->{_ip_int} = $ip_int;
     $iApp->{_host}   = gethostbyaddr( $ip_int, 2 ) || $ip;
 
-    require Digest::MD5;
     my $seed = $iConfig->get('Seed');
     $iApp->{_serial} = Digest::MD5::md5_hex( $from, $seed );
     1;
