@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Read.pm 1481 2007-10-24 14:13:30Z hikarin $
+# $Id: Read.pm 1645 2008-02-06 15:40:18Z hikarin $
 #
 
 package Img0ch::App::Read;
@@ -92,49 +92,6 @@ sub run {
     }
 }
 
-sub init {
-    my ( $iApp, $option ) = @_;
-    my $iConfig  = $iApp->{_config};
-    my $iRequest = $iApp->{_request};
-    my $mobile   = $option->{mobile};
-
-    $iConfig->get('Maintenance')
-        and die 'img0ch MAINTENANCE: Please try again later.', "\n";
-    $iRequest->init($iConfig);
-    $iApp->_parse_from_request( $iConfig, $iRequest, $mobile );
-
-    my $iBBS = Img0ch::BBS->new( $iApp->{_kernel},
-        { bbs => $iApp->{_param_bbs}, } );
-    if ( !$iBBS->get_id() ) {
-        $iApp->{__error} = 'INVALID_POST';
-        return 0;
-    }
-    $iApp->{_bbs} = $iBBS;
-
-    my $key = $iApp->{_param_key};
-
-    $iApp->{_setting} = $iBBS->get_setting_instance();
-    $iApp->{__now}    = $iRequest->now();
-
-    my $iThread = $iBBS->get_thread_instance(0);
-    $iThread->set_key($key);
-    my $count = $iThread->count();
-    ( !$count and !$mobile ) and return 0;
-
-    $iApp->{__agent}        = $iRequest->agent();
-    $iApp->{_thread}        = $iThread;
-    $iApp->{__thread_count} = $count;
-    $iApp->_normalize($mobile);
-
-    if ( !$iConfig->get( $option->{disable} ) ) {
-        my $iPlugin = $iBBS->get_plugin_instance($key);
-        $iPlugin->do( $option->{type}, $iApp ) or return 0;
-        $iApp->{_plugin} = $iPlugin;
-    }
-
-    1;
-}
-
 sub bbs { $_[0]->{_bbs} }
 
 sub kernel { $_[0]->{_kernel} }
@@ -180,7 +137,6 @@ sub load_thread {
 
     my $st        = $iApp->{__read_from};
     my $to        = $iApp->{__read_to};
-    my $br2nl     = $option->{br2nl};
     my $parameter = {
         %$option,
         line    => $iApp->get_param_int('LINE'),
@@ -198,13 +154,20 @@ sub load_thread {
         and $read_range->[0] == 1 )
     {
         my $first = $iThread->get(1);
-        my $id    = $first->[3];
-        my $name  = $first->[0];
-        my $date  = $id ? ( join ' ', $first->[2], $id ) : $first->[2];
         my $text  = $first->[4];
-        ( $mobile and $omit and $name eq $noname ) and $name = '';
-        $plugin->( $key, $count, 1, \$text, $parameter );
-        $br2nl and $text =~ s{<br\s*/?>}{\r}gxms;
+        $plugin->( $key, $count, 1, \$text, $parameter, $first );
+
+        my $id   = $first->[3];
+        my $name = $first->[0];
+        my $date = $id ? ( join ' ', $first->[2], $id ) : $first->[2];
+        my $textnt;
+        if ($mobile) {
+            ( $omit and $name eq $noname ) and $name = '';
+            $textnt = $text;
+            $textnt =~ s{<br\s*/?>}{\t}gxms;
+            $textnt =~ s{<[^>]+>}{}gxms;
+        }
+
         push @{$read_thread_stack},
             {
             index   => 1,
@@ -213,6 +176,7 @@ sub load_thread {
             mail    => $first->[1],
             date    => $date,
             text    => $text,
+            textNT  => $textnt,
             isFirst => 1,
             };
         shift @{$read_range};
@@ -220,13 +184,20 @@ sub load_thread {
 
     for my $i ( @{$read_range} ) {
         my $res  = $iThread->get($i);
+        my $text = $res->[4];
+        $plugin->( $key, $count, $i, \$text, $parameter, $res );
+
         my $id   = $res->[3];
         my $name = $res->[0];
         my $date = $id ? ( join ' ', $res->[2], $id ) : $res->[2];
-        my $text = $res->[4];
-        ( $mobile and $omit and $name eq $noname ) and $name = '';
-        $plugin->( $key, $count, $i, \$text, $parameter );
-        $br2nl and $text =~ s{<br\s*/?>}{\r}gxms;
+        my $textnt;
+        if ($mobile) {
+            ( $omit and $name eq $noname ) and $name = '';
+            $textnt = $text;
+            $textnt =~ s{<br\s*/?>}{\t}gxms;
+            $textnt =~ s{<[^>]+>}{}gxms;
+        }
+
         push @{$read_thread_stack},
             {
             index   => $i,
@@ -235,6 +206,7 @@ sub load_thread {
             mail    => $res->[1],
             date    => $date,
             text    => $text,
+            textNT  => $textnt,
             isFirst => 0,
             };
     }
@@ -269,9 +241,11 @@ sub load_thread {
     );
 
     $mobile or $st--;
-    my $r90  = ( $count >= $max - int( $max / 10 ) ? 1 : 0 );
-    my $r95  = ( $count >= $max - int( $max / 20 ) ? 1 : 0 );
-    my $r100 = ( $count > $max                     ? 1 : 0 );
+    my $r90c                = $max - int( $max / 10 );
+    my $r95c                = $max - int( $max / 20 );
+    my $r90                 = ( $count >= $r90c ? 1 : 0 );
+    my $r95                 = ( $count >= $r95c ? 1 : 0 );
+    my $r100                = ( $count > $max ? 1 : 0 );
     my $template_parameters = {
         ( map { %{$_} } @{ $iApp->{__template_tag_read} } ),
         '90'     => $r90,
@@ -280,9 +254,12 @@ sub load_thread {
         'R90'    => $r90,
         'R95'    => $r95,
         'R100'   => $r100,
+        'R90C'   => $r90c,
+        'R95C'   => $r95c,
         'Banner' => $mobile
         ? $iMeta->mobile_banner()
         : $iMeta->main_banner(),
+        'BBS_RES_MAX'  => $max,
         'DatKByteSize' => int( $iThread->size() / 1024 ),
         'KEY'          => $key,
         'key'          => $key,
@@ -290,8 +267,8 @@ sub load_thread {
 
         #       'NameByCookie' => ( $iRequest->cookie('NAME') || '' ),
         'NameByCookie' => '',
-        'NextEnd'      => ( $to + $read_res > $max ? $max : $to + $read_res ),
-        'NextStart'    => $to + 1,
+        'NextEnd' => ( $to + $read_res > $count ? $count : $to + $read_res ),
+        'NextStart' => $to + 1,
 
         #       'MailByCookie' => ( $iRequest->cookie('MAIL') || '' ),
         'MailByCookie' => '',
@@ -386,7 +363,6 @@ sub redirect_error {
         defined &{'Img0ch::Error::new'} or require Img0ch::Error;
         my $ip = $iRequest->ip_int();
         my $iError = Img0ch::Error->new( $iKernel, $key, $ip );
-        $iError->record();
         $is_error = 1;
         $long = $iError->get( $iApp->{__error} || 'INVALID_POST' );
     }
@@ -432,22 +408,43 @@ sub redirect_error {
     }
 }
 
-sub _parse_from_request {
-    my ( $iApp, $iConfig, $iRequest, $mobile ) = @_;
-    my $max_read = ( $iConfig->get_int('ResMAX') || 1000 ) + 1;
+sub init {
+    my ( $iApp, $option ) = @_;
+    my $iConfig  = $iApp->{_config};
+    my $iRequest = $iApp->{_request};
+    my $mobile   = $option->{mobile};
+    my ( $iBBS, $bbs, $key, $count, $last, $nofirst );
+
+    $iConfig->get('Maintenance')
+        and die 'img0ch MAINTENANCE: Please try again later.', "\n";
+    $iRequest->init($iConfig);
     my $temp_range = [];
 
     if ( my $path_info = $iRequest->path_info() ) {
-        $path_info =~ s{\A/?}{}gxms;
         my @path = split '/', $path_info;
         my $raw;
 
+        shift @path;
         'test'   =~ /\A(\w+)\z/xms;
         $path[0] =~ /\A([\w\-]+)\z/xms;
-        my $bbs = $iApp->{_param_bbs} = $1;
+        $bbs = $iApp->{_param_bbs} = $1;
         '0000000000' =~ /\A(\d+)\z/xms;
         $path[1]     =~ /\A(\d{9,10})\z/xms;
-        my $key = $iApp->{_param_key} = $1;
+        $key = $iApp->{_param_key} = $1;
+
+        $iBBS = Img0ch::BBS->new( $iApp->{_kernel}, { bbs => $bbs } );
+        if ( !$iBBS->get_id() ) {
+            $iApp->{__error} = 'INVALID_POST';
+            return 0;
+        }
+        $iApp->{_bbs} = $iBBS;
+
+        my $iThread = $iBBS->get_thread_instance(0);
+        $iThread->set_key($key);
+        $count = $iThread->count();
+        ( !$count and !$mobile ) and return 0;
+        $iApp->{_thread}        = $iThread;
+        $iApp->{__thread_count} = $count;
 
         my $extent_param_parser = sub {
             my ( $iApp, $parameter ) = @_;
@@ -527,7 +524,7 @@ sub _parse_from_request {
                 $param or next;
                 my ( $read_from, $read_to, $read_recent, $read_nofirst )
                     = @{ $main_parser->($param) };
-                $read_to ||= $max_read;
+                $read_to ||= $count;
                 $swap->( \$read_from, \$read_to );
                 map { $temp_range_hash->{$_} = 1 } (
                     ( $read_from .. $read_to ),
@@ -538,21 +535,22 @@ sub _parse_from_request {
             }
 
             #warn scalar keys %$temp_range_hash, "\n";
-            $iApp->{_param_ls}      = $param_recent;
-            $iApp->{_param_nofirst} = $param_nofirst;
+            $iApp->{_param_ls}      = $last    = $param_recent;
+            $iApp->{_param_nofirst} = $nofirst = $param_nofirst;
         }
         else {
             my @range = @{ $plus_separated_parser->($raw) };
             if ( !@range ) {
                 my ( $read_from, $read_to, $read_recent, $read_nofirst )
                     = @{ $main_parser->($raw) };
-                $iApp->{_param_ls} = $read_recent;
-                $read_to ||= $max_read;
+                $iApp->{_param_ls} = $last = $read_recent;
+                $read_to ||= $count;
                 my $single = $iApp->{_param_single}
                     = ( $read_from == $read_to and !$read_recent ) ? 1 : 0;
-                $iApp->{_param_nofirst} = ( $single || $read_nofirst );
-                $read_from > $max_read and $read_from = $max_read;
-                $read_to > $max_read   and $read_to   = $max_read;
+                $iApp->{_param_nofirst} = $nofirst
+                    = ( $single || $read_nofirst );
+                $read_from > $count and $read_from = $count;
+                $read_to > $count   and $read_to   = $count;
                 $swap->( \$read_from, \$read_to );
                 @range = ( $read_from .. $read_to );
             }
@@ -563,36 +561,45 @@ sub _parse_from_request {
     }
     else {
         $iApp->get_param('bbs') =~ /([\w\-]+)/xms;
-        $iApp->{_param_bbs} = $1;
+        $bbs = $iApp->{_param_bbs} = $1;
         '0000000000'            =~ /\A(\d+)\z/xms;
         $iApp->get_param('key') =~ /(\d{9,10})/;
-        $iApp->{_param_key} = $1;
+        $key = $iApp->{_param_key} = $1;
         $iApp->{_param_raw} = '';
+
+        $iBBS = Img0ch::BBS->new( $iApp->{_kernel}, { bbs => $bbs } );
+        if ( !$iBBS->get_id() ) {
+            $iApp->{__error} = 'INVALID_POST';
+            return 0;
+        }
+        $iApp->{_bbs} = $iBBS;
+
+        my $iThread = $iBBS->get_thread_instance(0);
+        $iThread->set_key($key);
+        $count = $iThread->count();
+        ( !$count and !$mobile ) and return 0;
+        $iApp->{_thread}        = $iThread;
+        $iApp->{__thread_count} = $count;
+
         my $read_from = Img0ch::Kernel::intval( $iApp->get_param('st') ) || 1;
         my $read_to = Img0ch::Kernel::intval( $iApp->get_param('to') )
-            || $max_read;
-        my $read_recent = $iApp->{_param_ls} = $iApp->get_param('last')
+            || $count;
+        $iApp->{_param_ls} = $last
+            || $iApp->get_param('last')
             || $iApp->get_param('ls');
         my $single = $iApp->{_param_single}
-            = ( $read_from == $read_to and !$read_recent ) ? 1 : 0;
-        $iApp->{_param_nofirst} = ( $single
+            = ( $read_from == $read_to and !$last ) ? 1 : 0;
+        $iApp->{_param_nofirst} = $nofirst = ( $single
                 || ( $iApp->get_param('nofirst') eq 'true' ? 1 : 0 ) );
-        $read_from > $max_read and $read_from = $max_read;
-        $read_to > $max_read   and $read_to   = $max_read;
+        $read_from > $count and $read_from = $count;
+        $read_to > $count   and $read_to   = $count;
         push @{$temp_range}, sort { $a <=> $b } ( $read_from .. $read_to );
     }
-    @{ $iApp->{__range_read} } = @{$temp_range};
 
-    1;
-}
-
-sub _normalize {
-    my ( $iApp, $is_mobile ) = @_;
-    my $temp_range     = $iApp->{__range_read};
+    $iApp->{_setting} = $iBBS->get_setting_instance();
+    $iApp->{__now}    = $iRequest->now();
+    $iApp->{__agent}  = $iRequest->agent();
     my $raw            = $iApp->{_param_raw};
-    my $last           = $iApp->{_param_ls};
-    my $nofirst        = $iApp->{_param_nofirst};
-    my $res_count      = $iApp->{__thread_count};
     my $temp_read_from = $temp_range->[0] || 1;
     my $temp_read_to   = $temp_range->[-1] || $temp_read_from;
     my ( $real_read_from, $real_read_to, $read_by_const ) = (
@@ -603,7 +610,7 @@ sub _normalize {
         )
     );
 
-    if ($is_mobile) {
+    if ($mobile) {
         $read_by_const--;
         if ( $raw =~ /\A(n)?[acCi]*\z/xms ) {
             $last = 1;
@@ -627,11 +634,11 @@ sub _normalize {
     }
 
     if ($last) {
-        my $first = $res_count - $temp_read_to;
+        my $first = $count - $temp_read_to;
         $real_read_from = $first > 0 ? $first : 1;
-        ( !$is_mobile ) and $read_by_const = $temp_read_to;
+        ( !$mobile ) and $read_by_const = $temp_read_to;
         my $read_to = $real_read_from + $read_by_const;
-        $real_read_to = $res_count > $read_to ? $read_to : $res_count;
+        $real_read_to = $count > $read_to ? $read_to : $count;
         @{$temp_range} = $real_read_from .. $real_read_to;
         $iApp->{__read_from} = $real_read_from;
         $iApp->{__read_to}   = $real_read_to;
@@ -649,11 +656,11 @@ sub _normalize {
             $temp_range->[0] != 1 and unshift @{$temp_range}, 1;
         }
         $real_read_to
-            = ( $temp_read_to < $res_count ) ? $temp_read_to
+            = ( $temp_read_to < $count ) ? $temp_read_to
             : (
-            ( $is_mobile and $temp_read_from != $temp_read_to )
+            ( $mobile and $temp_read_from != $temp_read_to )
             ? $real_read_from + $read_by_const
-            : $res_count
+            : $count
             );
         $iApp->{__read_from} = $temp_read_from;
         $iApp->{__read_to}   = $real_read_to;
@@ -666,12 +673,18 @@ sub _normalize {
     foreach my $i ( @{$temp_range} ) {
         ( $i < $real_read_from ) and next;
         ( $i > $real_read_to )   and next;
-        ( $i > $res_count )      and next;
+        ( $i > $count )          and next;
         push @{$real_range}, $i;
     }
     @{ $iApp->{__range_read} } = @{$real_range};
 
-    1;
+    if ( !$iConfig->get( $option->{disable} ) ) {
+        my $iPlugin = $iBBS->get_plugin_instance($key);
+        $iPlugin->do( $option->{type}, $iApp ) or return 0;
+        $iApp->{_plugin} = $iPlugin;
+    }
+
+    return 1;
 }
 
 1;
