@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: UFM.pm 1285 2007-10-05 14:47:29Z hikarin $
+# $Id: UFM.pm 1645 2008-02-06 15:40:18Z hikarin $
 #
 
 package Img0ch::App::UFM;
@@ -99,9 +99,11 @@ sub process {
     my $iBBS     = $iApp->{__bbs};
     my $iRequest = $iApp->{__request};
     my $iUpload  = $iApp->{__upload} = $iBBS->get_upload_instance($key);
-    my $pass     = $iRequest->param('pass');
-    my $type     = $iRequest->param('type');
-    my $process  = {};
+    $iUpload->get($resno)->[0] or return ( 0, undef, '', \'' );
+
+    my $pass    = $iRequest->param('pass');
+    my $type    = $iRequest->param('type');
+    my $process = {};
 
     if ($pass) {
         my $js = {};
@@ -150,8 +152,7 @@ sub process {
         my $comment  = $iRequest->param('comment');
         my $ip       = $iRequest->ip();
         my $maxlen   = $iSetting->get_int('BBS_IMG_POLL_COMMENT_COUNT');
-        if (    $iUpload->get($resno)->[0]
-            and $iApp->validate_poll( $ip, $agent, $comment, $maxlen )
+        if ($iApp->validate_poll( $ip, $agent, $comment, $maxlen )
             and $iUPoll->can_poll(
                 $TAG,
                 $iRequest->ip(),
@@ -174,6 +175,60 @@ sub process {
             $process->{polled} = 0;
         }
     }
+    elsif ( $type eq 'rate' ) {
+        defined &{'Img0ch::Upload::Poll::new'}
+            or require Img0ch::Upload::Poll;
+        my $iSetting = $iApp->{__setting};
+        my $iUPoll   = Img0ch::Upload::Poll->new( $iBBS, $key );
+        my $agent    = $iRequest->agent();
+        my $comment  = $iRequest->param('comment');
+        my $rate     = $iRequest->param_int('rate');
+        my $ip       = $iRequest->ip();
+        my $maxlen = $iSetting->get_int('BBS_IMG_POLL_COMMENT_COUNT') || 255;
+
+        if ( $iApp->validate_poll( $ip, $agent, $comment, $maxlen ) ) {
+            $rate < 1 or $rate > 5 and $rate = 3;
+            $comment = join "\n", $rate, $comment;
+            if ( $iUPoll->add( $resno, 'STAR', $ip, $comment, undef, 1 ) ) {
+                $iUPoll->save();
+                $process->{rated} = 1;
+            }
+            else {
+                $process->{rate} = 0;
+            }
+        }
+        else {
+            $process->{rated} = 0;
+        }
+    }
+    elsif ( $type eq 'tagging' ) {
+        defined &{'Img0ch::Upload::Tag::new'}
+            or require Img0ch::Upload::Tag;
+        my $iConfig = $iApp->{__config};
+        if ( !$iConfig->get('search.disable_upload_tag') ) {
+            my $iUTag  = Img0ch::Upload::Tag->new($iBBS);
+            my $maxcnt = $iConfig->get_int('ufm.tag_max_count') || 10;
+            my $maxlen = $iConfig->get_int('ufm.tag_max_length') || 32;
+            my $ip     = $iRequest->ip();
+            my $tags   = [
+                grep { length($_) <= $maxlen } split /\s+/xms,
+                $iRequest->param('tag')
+            ];
+            scalar @$tags > $maxcnt and @$tags = splice @$tags, 0, $maxcnt;
+            if ( $iApp->can_post($ip) ) {
+                $iUTag->set( $key, $resno, $ip, $tags );
+                $iUTag->save();
+                $iApp->save_tag_json($iUTag);
+                $process->{tagged} = 1;
+            }
+            else {
+                $process->{tagged} = 0;
+            }
+        }
+        else {
+            $process->{tagged} = 0;
+        }
+    }
 
     return $iApp->render( $process, $key, $resno, $pass, );
 }
@@ -183,13 +238,16 @@ sub load_poll {
 
     defined &{'Img0ch::Upload::Poll::new'} or require Img0ch::Upload::Poll;
     my $iUPoll = Img0ch::Upload::Poll->new( $iApp->{__bbs}, $key );
-    my $ret = $iUPoll->get( $resno, $TAG );
+    my $ret    = $iUPoll->get( $resno,                      $TAG );
+    my $i      = 1;
     for my $one (@$ret) {
         my @d = localtime( $one->{polled} );
         $d[5] += 1900;
         $d[4] += 1;
+        $one->{resno} = $i;
         $one->{polled} = sprintf '%02d/%02d/%02d %02d:%02d:%02d', $d[5],
             $d[4], $d[3], $d[2], $d[1], $d[0];
+        $i++;
     }
 
     return {
@@ -203,13 +261,71 @@ sub load_poll {
     };
 }
 
+sub load_review {
+    my ( $iApp, $key, $resno ) = @_;
+
+    defined &{'Img0ch::Upload::Poll::new'} or require Img0ch::Upload::Poll;
+    my $iUPoll = Img0ch::Upload::Poll->new( $iApp->{__bbs}, $key );
+    my $ret    = $iUPoll->get( $resno,                      'STAR' );
+    my $i      = 1;
+    for my $one (@$ret) {
+        my ( $rate, $comment ) = split "\n", $one->{comment};
+        my @d = localtime( $one->{polled} );
+        $d[5] += 1900;
+        $d[4] += 1;
+        $one->{resno}    = $i;
+        $one->{comment}  = $comment;
+        $one->{rate}     = $rate;
+        $one->{reviewed} = sprintf '%02d/%02d/%02d %02d:%02d:%02d', $d[5],
+            $d[4], $d[3], $d[2], $d[1], $d[0];
+        $i++;
+    }
+
+    defined $List::Util::VERSION or require List::Util;
+    my $count = scalar @$ret || 1;
+    my $average = List::Util::sum( map { $_->{rate} } @$ret ) / $count;
+    return {
+        Reviews     => $ret,
+        ReviewCount => $count,
+        RateAverage => sprintf( '%01.1f', $average ),
+    };
+}
+
 sub validate_poll {
     my ( $iApp, $ip, $agent, $comment, $maxlen ) = @_;
     !$comment                 and return 0;
     length $comment > $maxlen and return 0;
     $agent                    and return 0;
+    $iApp->can_post($ip) or return 0;
+    return 1;
+}
 
+sub save_tag_json {
+    my ( $iApp, $iUTag ) = @_;
+    my $iKernel = $iApp->{__kernel};
+    my ( $fh, $path );
+
+    $path = $iApp->{__bbs}->path( 'img', 'tag.json' );
+    open $fh, '>', $path or $iKernel->throw_io_exception($path);
+    print $fh ${ $iUTag->to_json() }
+        or $iKernel->throw_io_exception($path);
+    close $fh or $iKernel->throw_io_exception($path);
+
+    if ( my $key = $iApp->{__key} ) {
+        $path = join '/', $iApp->{__upload}->path(), 'tag.json';
+        open $fh, '>', $path or $iKernel->throw_io_exception($path);
+        print $fh ${ $iUTag->to_json($key) }
+            or $iKernel->throw_io_exception($path);
+        close $fh or $iKernel->throw_io_exception($path);
+    }
+
+    return 1;
+}
+
+sub can_post {
+    my ( $iApp, $ip ) = @_;
     my $iConfig = $iApp->{__config};
+
     if ( !$iConfig->get('ufm.skip_check_dnsbl') ) {
         defined &{'Img0ch::Plugin::Module::DNSBL::is_in_dnsbl'}
             or require Img0ch::Plugin::Module::DNSBL;
@@ -256,11 +372,6 @@ sub render {
         $i++;
     }
 
-    my $poll = {};
-    if ( $key_param and $resno_param ) {
-        %$poll = %{ $iApp->load_poll( $key_param, $resno_param ) };
-    }
-
     my $iMeta     = $iBBS->get_metadata_instance();
     my $iTemplate = $iBBS->get_template_instance(
         {   file    => 'ufm',
@@ -269,23 +380,73 @@ sub render {
         }
     );
 
-    my $removed       = $process->{removed};
-    my $really_polled = exists $process->{polled};
-    my $polled_result = $process->{polled};
+    my $removed = $process->{removed};
+    my $status  = {};
+    for my $key (qw(polled rated tagged)) {
+        my $really_did   = exists $process->{$key};
+        my $result       = $process->{$key};
+        my $template_key = ucfirst $key;
+        $status->{"${template_key}OK"} = ( $really_did and $result );
+        $status->{"${template_key}NG"} = ( $really_did and !$result );
+    }
+
+    my $poll_rate = {};
+    my $poll_bad  = {};
+    if ( $key_param and $resno_param ) {
+        %$poll_rate = %{ $iApp->load_review( $key_param, $resno_param ) };
+        %$poll_bad  = %{ $iApp->load_poll( $key_param,   $resno_param ) };
+    }
+
+    defined $HTML::TagClound::VERSION     or require HTML::TagCloud;
+    defined &{'Img0ch::Upload::Tag::new'} or require Img0ch::Upload::Tag;
+    my $my_tags_stack   = [];
+    my $tag_cloud_stack = [];
+    my $level           = $iConfig->get_int('tagcloud.level') || 24;
+    my $max             = $iConfig->get_int('tagcloud.max') || 50;
+    my $ip              = $iRequest->ip();
+    my $cloud           = HTML::TagCloud->new( levels => $level );
+    my $iUTag           = Img0ch::Upload::Tag->new($iBBS);
+    my $tags_data       = $iUTag->get( $key_param, $resno_param );
+    my $uri             = join '/', $iRequest->get_app_uri(), 'img0ch-sf.cgi',
+        $iBBS->get_name();
+
+    while ( my ( $name, $info ) = each %$tags_data ) {
+        $cloud->add( $name, join( '/', $uri, $iRequest->escape_uri($name) ),
+            $info->[0] );
+        scalar grep { $_ eq $ip } @{ $info->[1] }
+            and push @$my_tags_stack, $name;
+    }
+    for my $tag ( $cloud->tags($max) ) {
+        push @$tag_cloud_stack,
+            {
+            count => $tag->{count},
+            level => $tag->{level},
+            name  => $tag->{name},
+            url   => $tag->{url},
+            };
+    }
+
     $iTemplate->param(
         {   Banner          => $iMeta->main_banner(),
             DisplayPolledIP => ( $iConfig->get('ufm.no_polled_ip') ? 0 : 1 ),
             Freezed         => $process->{freezed},
             KEY             => $key_param,
             META            => $iMeta->meta(),
-            Password        => $pass_param,
-            PolledOK => ( $really_polled and $polled_result ),
-            PolledNG => ( $really_polled and !$polled_result ),
+            MyTags   => join( ' ', sort @$my_tags_stack ),
+            Password => $pass_param,
             Removed  => $removed,
-            Failed   => ( $pass_param    and !$removed ),
-            Resno    => $resno_param,
-            Threads  => $stack,
-            %$poll,
+            Failed => ( $pass_param and !$removed ),
+            Resno => $resno_param,
+            TagCloud      => $tag_cloud_stack,
+            TagCloudHTML  => $cloud->html($max),
+            TagCloudCSS   => $cloud->css(),
+            TagCloudLevel => [ map {$_} ( 1 .. $level ) ],
+            TagMaxCount  => ( $iConfig->get('ufm.tag_max_count')  || 10 ),
+            TagMaxLength => ( $iConfig->get('ufm.tag_max_length') || 32 ),
+            Threads      => $stack,
+            %$poll_rate,
+            %$poll_bad,
+            %$status,
         }
     );
 
@@ -302,7 +463,6 @@ sub redirect_error {
     defined &{'Img0ch::Error::new'} or require Img0ch::Error;
     my $iError = Img0ch::Error->new( $iKernel, $key, $ip );
     my $long = $iError->get( $iApp->{__error} || 'INVALID_POST' );
-    $iError->record();
 
     if ( $iRequest->param('js') ) {
         $iRequest->send_http_header( 'text/javascript', 'UTF-8' );
