@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Oekaki.pm 363 2007-03-16 15:11:10Z hikarin $
+# $Id: Oekaki.pm 1645 2008-02-06 15:40:18Z hikarin $
 #
 
 package Img0ch::Compat::App::Oekaki;
@@ -33,7 +33,7 @@ sub create_animation {
     {
         my $iBBS    = $iApp->bbs();
         my $iKernel = $iApp->kernel;
-        my $iUpload = Img0ch::Upload->new( $iBBS, $key );
+        my $iUpload = $iBBS->get_upload_instance($key);
         if ( -r $iUpload->path( $resno, 'pch' ) ) {
             $url = $iUpload->url( $resno, 'pch' );
             $magic = 'P';
@@ -62,7 +62,7 @@ sub load_pch {
     {
         my $iBBS     = $iApp->bbs();
         my $iKernel  = $iApp->kernel();
-        my $iUpload  = Img0ch::Upload->new( $iBBS, $key );
+        my $iUpload  = $iBBS->get_upload_instance($key);
         my $pch_file = $iUpload->path( $resno, 'pch' );
         if ( !-r $pch_file ) {
             $pch_file = $iUpload->path( $resno, 'spch' );
@@ -70,11 +70,9 @@ sub load_pch {
                 return ( undef, 'application/octet-stream', \$pch );
             }
         }
-        local ( *FH, $! );
-        open *FH, $pch_file    ## no critic
-            or $iKernel->throw_io_exception($pch_file);
-        $pch = do { local $/; <FH> };
-        close *FH or $iKernel->throw_io_exception($pch_file);
+        my $fh = $iKernel->get_read_file_handle($pch_file);
+        $pch = do { local $/; <$fh> };
+        close $fh or $iKernel->throw_io_exception($pch_file);
         return ( undef, 'application/octet-stream', \$pch );
     }
     return $iApp->{__parent}->{pch}->($iApp);
@@ -88,8 +86,7 @@ sub create_confirm_password {
 
     my $iTemplate = $iApp->{__parent}->{confirm}->( $iApp, $key, $resno );
     if ( my $input = $iRequest->param('editpass') ) {
-        require Img0ch::Thread;
-        my $iThread = Img0ch::Thread->new( $iApp->bbs(), $key );
+        my $iThread = $iApp->bbs()->get_thread_instance($key);
         $iThread->load();
         my $res       = $iThread->get($resno);
         my $trip_mark = $iApp->config()->get('multibyte.TRUE_TRIP')
@@ -165,13 +162,12 @@ sub search_from_directory {
     my ( $iApp, $path, $code ) = @_;
     my $iKernel = $iApp->kernel();
     my $result  = {};
-    local ( *DH, $! );
 
-    opendir *DH, $path or $iKernel->throw_io_exception($path);
-    my @file = readdir *DH;
-    closedir *DH or $iKernel->throw_io_exception($path);
+    opendir my $fh, $path or $iKernel->throw_io_exception($path);
+    my @file = readdir $fh;
+    closedir $fh or $iKernel->throw_io_exception($path);
 
-    require File::Spec;
+    defined $File::Spec::VERSION or require File::Spec;
     for my $found ( grep /\A$code.*?\.(?:jpg|png|s?pch)\z/xms, @file ) {
         my ( undef, $extension ) = split '\.', $found;
         $result->{$extension} = File::Spec->catfile( $path, $found );
@@ -193,13 +189,11 @@ sub get_crypt {
 sub slurp_binary {
     my ( $iApp, $path ) = @_;
     my $iKernel = $iApp->kernel();
-    local ( *FH, $! );
 
-    open *FH, "<${path}"    ## no critic
-        or $iKernel->throw_io_exception($path);
-    binmode *FH;
-    my $buffer = do { local $/ = undef; <FH> };
-    close *FH or $iKernel->throw_io_exception($path);
+    my $fh = $iKernel->get_read_file_handle($path);
+    my $buffer = do { local $/ = undef; <$fh> };
+    close $fh or $iKernel->throw_io_exception($path);
+
     return \$buffer;
 }
 
