@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Error.pm 1481 2007-10-24 14:13:30Z hikarin $
+# $Id: Error.pm 1645 2008-02-06 15:40:18Z hikarin $
 #
 
 package Img0ch::Error;
@@ -85,9 +85,12 @@ sub get {
 
 sub add {
     my ($iError) = @_;
-    if (    my $cache = $iError->{__cache}
-        and my $ip_int = $iError->{__ip} )
-    {
+    my $cache = $iError->{__cache};
+    my %stop_to_add = map { ( $_ => 1 ) } 
+        qw(DENY_POSTING_ASCII_ONLY INVALID_POST POST_WITH_NGWORD TOO_LONG_MESSAGE);
+
+    if ($cache and !exists $stop_to_add{$cache} 
+        and my $ip_int = $iError->{__ip} ) {
         my $iRepos = $iError->{_rs};
         my $bbs    = $iError->{_bbs};
         my $key    = $iError->{__key};
@@ -99,7 +102,8 @@ sub add {
         $iRepos->save();
         return 1;
     }
-    0;
+
+    return 0;
 }
 
 *record = \&add;
