@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,32 +14,40 @@
 # *  limitations under the License.
 # */
 #
-# $Id: BootStrap.pm 715 2007-05-29 13:14:36Z hikarin $
+# $Id: BootStrap.pm 1645 2008-02-06 15:40:18Z hikarin $
 #
 
 package Img0ch::FCGI::BootStrap;
 
 use strict;
-use CGI::Fast qw();
 use File::Basename qw();
+use FCGI::ProcManager qw();
 use Img0ch::Config qw();
 use Img0ch::FCGI::Request qw();
 use Img0ch::Maple qw();
 
 my $img0ch_config_modified = 0;
+
 sub import {
     my ( $iBootstrap, $app ) = @_;
     my $iConfig = Img0ch::Config->new();
     eval "use ${app} qw(); 1" or die $@, "\n";
 
+    my $processes = $ENV{PM_N_PROCESSES} || 5;
+    my $FCGIPM = FCGI::ProcManager->new( { n_processes => $processes } );
+    $FCGIPM->pm_manage();
+
+    require CGI::Fast;
+SERVER:
     while ( my $q = CGI::Fast->new() ) {
-        my $base     = $q->script_name() || $0;
+        $FCGIPM->pm_pre_dispatch();
+        my $base     = $ENV{SCRIPT_FILENAME} || $0;
         my $path     = File::Basename::dirname($base) . '/img0ch-config.cgi';
-        my $modified = (stat($path))[9];
+        my $modified = ( stat($path) )[9];
         if ( ( $img0ch_config_modified ||= $modified ) < $modified ) {
-            print {*STDERR} '[', scalar(localtime(time())),
+            my $message = join '', '[', scalar( localtime( time() ) ),
                 '] restarted FastCGI application: ', $app, "\n";
-            last;
+            $FCGIPM->pm_die($message);
         }
         eval {
             $iConfig->load($path);
@@ -51,6 +59,7 @@ sub import {
             $errstr =~ s/\s/&nbsp;/gxms;
             print 'Content-type: text/html', "\n\n", $errstr, "\n";
         }
+        $FCGIPM->pm_post_dispatch();
     }
 }
 
