@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,13 +14,22 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Request.pm 1481 2007-10-24 14:13:30Z hikarin $
+# $Id: Request.pm 1645 2008-02-06 15:40:18Z hikarin $
 #
 
 package Img0ch::ModPerl2::Request;
 
 use strict;
 use base qw(Img0ch::Request::Interface);
+use mod_perl2 qw();
+use Apache2::Connection qw();
+use Apache2::Const qw(-compile);
+use Apache2::Request qw();
+use Apache2::RequestIO qw();
+use Apache2::RequestRec qw();
+use Apache2::RequestUtil qw();
+use Apache2::Response qw();
+use Apache2::Upload qw();
 
 BEGIN { $INC{'Img0ch/Request.pm'} = __FILE__ }
 
@@ -124,7 +133,7 @@ sub request_uri { $_[0]->get_header('request-uri') }
 
 sub query { $_[0]->{__apache}->args() }
 
-sub path_info { $_[0]->{__apache}->path_info() }
+sub path_info { substr $_[0]->{__apache}->path_info(), 1 }
 
 sub is_uploadable {
     my ( $iRequest, $key ) = @_;
