@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Install.pm 900 2007-07-14 14:27:12Z hikarin $
+# $Id: Install.pm 1645 2008-02-06 15:40:18Z hikarin $
 #
 
 package Img0ch::Plugin::Install;
@@ -58,6 +58,11 @@ sub install {
             methods => { rewrite => 'bbs.write.pre', },
         }
     );
+    $zPlugin->install(
+        {   package => 'Img0ch::Plugin::BBS::Reaper',
+            methods => { work => 'bbs.write.post', },
+        }
+    );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::BBS::UTF8Dat',
             methods => {
@@ -121,8 +126,18 @@ sub install {
             methods => { check => 'bbs.filter', },
         }
     );
+#    $zPlugin->install(
+#        {   package => 'Img0ch::Plugin::Filter::NGWord',
+#            methods => { check => 'bbs.filter', },
+#        }
+#    );
     $zPlugin->install(
-        {   package => 'Img0ch::Plugin::Filter::NGWord',
+        {   package => 'Img0ch::Plugin::Filter::NGWord2',
+            methods => { check => 'bbs.filter', },
+        }
+    );
+    $zPlugin->install(
+        {   package => 'Img0ch::Plugin::Filter::NoLink',
             methods => { check => 'bbs.filter', },
         }
     );
