@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Thread.pm 970 2007-08-21 14:52:15Z hikarin $
+# $Id: Thread.pm 1645 2008-02-06 15:40:18Z hikarin $
 #
 
 package Img0ch::Pool::Thread;
@@ -27,34 +27,45 @@ sub new {
     my $iKernel = $iBBS->get_kernel();
 
     my $pool_thread_dir
-        = Img0ch::Maple::create_repository_subdirs( $key, $key, $iKernel );
+        = Img0ch::Maple::create_repository_subdirs( $key, $key, $iBBS );
     $pool_thread_dir =~ s{/$key.\w+\z}{}xms;
+    my $pool_thread_dir2
+        = Img0ch::Maple::create_repository_subdirs( $key, $key, $iKernel );
+    $pool_thread_dir2 =~ s{/$key.\w+\z}{}xms;
+    my $pool_thread_dir3 = $pool_thread_dir2;
+    $pool_thread_dir3 =~ s{/\d+\z}{}xms;
 
     bless {
         _bbs      => $iBBS->get_name(),
         _count    => 0,
         _encoding => $iKernel->get_encoding(1),
+        _i0_bbs   => $iBBS,
         _kernel   => $iKernel,
         _key      => $key,
         _line     => [],
         __path    => $pool_thread_dir,
+        __path1   => $pool_thread_dir,
+        __path2   => $pool_thread_dir2,
+        __path3   => $pool_thread_dir3,
     }, $iClass;
 }
 
 sub load {
     my ( $iPool, $path ) = @_;
     my $changed = 0;
-    my $old     = $iPool->{__path};
 
     if ( !$path and !-e $iPool->path() ) {
-        my $pool_thread_dir = $old;
-        $pool_thread_dir =~ s{/\d+\z}{}xms;
-        $iPool->{__path} = $pool_thread_dir;
+        $iPool->{__path} = $iPool->{__path2};
+        $path = $iPool->path();
+        if ( !-e $path ) {
+            $iPool->{__path} = $iPool->{__path3};
+            $path = $iPool->path();
+        }
         $changed = 1;
     }
 
     my $ret = $iPool->SUPER::load($path);
-    $changed and $iPool->{__path} = $old;
+    $changed and $iPool->{__path} = $iPool->{__path1};
 
     return $ret;
 }
@@ -91,39 +102,51 @@ sub set {
 
 sub set_key {
     my ( $iPool, $key ) = @_;
-    my $iKernel = $iPool->{_kernel};
 
     my $pool_thread_dir
-        = Img0ch::Maple::create_repository_subdirs( $key, $key, $iKernel );
+        = Img0ch::Maple::create_repository_subdirs( $key, $key,
+        $iPool->{_i0_bbs} );
     $pool_thread_dir =~ s{/$key.\w+\z}{}xms;
+    my $pool_thread_dir2
+        = Img0ch::Maple::create_repository_subdirs( $key, $key,
+        $iPool->{_kernel} );
+    $pool_thread_dir2 =~ s{/$key.\w+\z}{}xms;
+    my $pool_thread_dir3 = $pool_thread_dir2;
+    $pool_thread_dir3 =~ s{/\d+\z}{}xms;
+
+    $iPool->{_key}    = $key;
+    $iPool->{__path}  = $pool_thread_dir;
+    $iPool->{__path1} = $pool_thread_dir;
+    $iPool->{__path2} = $pool_thread_dir2;
+    $iPool->{__path3} = $pool_thread_dir3;
 
-    $iPool->{_key}   = $key;
-    $iPool->{__path} = $pool_thread_dir;
     $iPool->SUPER::set_key($key);
 }
 
 sub remove {
     my ($iPool) = @_;
     my $changed = 0;
-    my $old     = $iPool->{__path};
+    my $path    = $iPool->path();
 
-    if ( !-r $iPool->path() ) {
-        my $pool_thread_dir = $old;
-        $pool_thread_dir =~ s{/\d+\z}{}xms;
-        $iPool->{__path} = $pool_thread_dir;
+    if ( !-e $path ) {
+        $iPool->{__path} = $iPool->{__path2};
+        $path = $iPool->path();
+        if ( !-e $path ) {
+            $iPool->{__path} = $iPool->{__path3};
+            $path = $iPool->path();
+        }
         $changed = 1;
     }
 
-    my $path = $iPool->path();
-    $changed and $iPool->{__path} = $old;
-
     if ( -w $path ) {
         my $iKernel = $iPool->{_kernel};
         unlink $path or $iKernel->throw_io_exception($path);
         $iPool->{_count} = 0;
+        $changed and $iPool->{__path} = $iPool->{__path1};
         return 1;
     }
     else {
+        $changed and $iPool->{__path} = $iPool->{__path1};
         return 0;
     }
 }
