@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Interface.pm 950 2007-08-04 15:39:03Z hikarin $
+# $Id: Interface.pm 1645 2008-02-06 15:40:18Z hikarin $
 #
 
 package Img0ch::Request::Interface;
@@ -97,7 +97,7 @@ sub param_multibyte {
 sub upload {
     my ( $iRequest, $path ) = @_;
     my $temp = $iRequest->tempfile();
-    require File::Copy;
+    defined $File::Copy::VERSION or require File::Copy;
     if ( !File::Copy::copy( $temp, $path ) ) {
         my $file = !-e $temp ? $temp : $path;
         Img0ch::Kernel->throw_io_exception($file);
@@ -109,7 +109,7 @@ sub upload {
 sub tempfile {
     my ($iRequest) = @_;
     my $tmp = $iRequest->{__tmp};
-    $tmp or die 'No file was uploaded', "\n";
+    $tmp or Img0ch::Kernel->throw_exception('No file was uploaded');
     return $tmp;
 }
 
@@ -122,15 +122,22 @@ sub filename {
 
 sub get_json {
     my ( $iRequest, $data ) = @_;
-    if ( eval 'use JSON::XS qw(); 1' ) {
-        return \JSON::XS::to_json($data);
+    if ( defined $JSON::XS::VERSION or eval 'use JSON::XS qw(); 1' ) {
+        return \JSON::XS->new()->encode($data);
     }
     else {
-        require Data::JavaScript::Anon;
+        defined $Data::JavaScript::Anon::VERSION
+            or require Data::JavaScript::Anon;
         return \Data::JavaScript::Anon->anon_dump($data);
     }
 }
 
+sub get_xml {
+    my ( $iRequest, $data ) = @_;
+    defined $XML::TreePP::VERSION or require XML::TreePP;
+    return \XML::TreePP->new()->write($data);
+}
+
 # from URI::Escape
 my %escapes;
 for ( 0 .. 255 ) {
@@ -227,7 +234,8 @@ sub detect_agent {
     my @jig      = keys %{ $iConfig->get('jig.*') };
     my @ibis     = keys %{ $iConfig->get('ibis.*') };
     my $ret      = eval {
-        require Net::IP::Match::XS;
+        defined $Net::IP::Match::XS::VERSION
+            or require Net::IP::Match::XS;
         Net::IP::Match::XS::match_ip( $host, @docomo )   and return 1;
         Net::IP::Match::XS::match_ip( $host, @vodafone ) and return 2;
         Net::IP::Match::XS::match_ip( $host, @au )       and return 3;
@@ -236,16 +244,17 @@ sub detect_agent {
         Net::IP::Match::XS::match_ip( $host, @ibis )     and return 6;
         return 0;
     };
-    return $ret unless $@;
+    $@ or return $ret;
 
-    require Net::CIDR::Lite;
+    defined $Net::CIDR::Lite::VERSION or require Net::CIDR::Lite;
     Net::CIDR::Lite->new(@docomo)->find($host)   and return 1;
     Net::CIDR::Lite->new(@vodafone)->find($host) and return 2;
     Net::CIDR::Lite->new(@au)->find($host)       and return 3;
     Net::CIDR::Lite->new(@willcom)->find($host)  and return 4;
     Net::CIDR::Lite->new(@jig)->find($host)      and return 5;
     Net::CIDR::Lite->new(@ibis)->find($host)     and return 6;
-    0;
+
+    return 0;
 }
 
 sub agent { $_[0]->{__agent} || 0 }
@@ -398,7 +407,7 @@ $reference_to_json_string
 
 =back
 
-データ構造をJSONに変換します。利用可能な場合はI<JSON::Syck>、
+データ構造をJSONに変換します。利用可能な場合はI<JSON::XS>、
 それ以外の場合にはI<Data::JavaScript::Anon>が利用されます。
 
 =head2 get_remote_host
