@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Cap.pm 252 2007-02-17 13:24:49Z hikarin $
+# $Id: Cap.pm 1645 2008-02-06 15:40:18Z hikarin $
 #
 
 package Zeromin::Cap;
@@ -29,7 +29,7 @@ sub new {
     my ( $iKernel, $zCap );
 
     $pass ||= '';
-    if ( $class eq 'Img0ch::BBS' ) {
+    if ( $class eq 'Img0ch::BBS' or $class eq 'Zeromin::BBS' ) {
         $iKernel      = $iObject->get_kernel();
         $zCap         = $zClass->SUPER::new( $iObject, $pass );
         $zCap->{_bbs} = $iObject->get_id();
@@ -62,10 +62,11 @@ sub save {
     my $cp = $zCap->{__cap_pool};
     for my $id ( keys %{$cp} ) {
         my $value = $cp->{$id};
-        my $name  = $value->{name} || '';
+        my $name = $value->{name} || '';
+        $name =~ tr/\r\n//d;
         $iRepos->set( "I:C:I.${id}.name", $name );
-        $iRepos->set( "I:C:I.${id}.raw",  $value->{raw}  || '' );
-        $iRepos->set( "I:C:I.${id}.gid",  $value->{gid}  || 0 );
+        $iRepos->set( "I:C:I.${id}.raw",  $value->{raw} || '' );
+        $iRepos->set( "I:C:I.${id}.gid",  $value->{gid} || 0 );
         $iRepos->set( "I:C:I.${name}.id", $id );
     }
 
@@ -73,9 +74,10 @@ sub save {
     for my $id ( keys %{$gp} ) {
         my $value = $gp->{$id};
         my $name = $value->{name} || '';
-        $iRepos->set( "I:C:G.${id}.name",      $name                    );
+        $name =~ tr/\r\n//d;
+        $iRepos->set( "I:C:G.${id}.name",      $name );
         $iRepos->set( "I:C:G.${id}.privilege", $value->{privilege} || 0 );
-        $iRepos->set( "I:C:G.${name}.id",      $id                      );
+        $iRepos->set( "I:C:G.${name}.id",      $id );
         for my $bbs ( @{ $value->{bbs} } ) {
             $iRepos->set( "I:C:G:S.${id}.${bbs}", 1 );
         }
@@ -97,9 +99,12 @@ sub add {
     my ( $zCap, $cap ) = @_;
     $zCap->get_group_name( $cap->{gid} ) or return 0;
     my $pass = delete $cap->{pass} || '';
-    my $cid = Digest::MD5::md5_base64($pass);
-    $zCap->get_cap_raw_pass($cid) eq $pass and return 0;
+    my $cid = Digest::MD5::md5_hex($pass);
+    (          $zCap->get_cap_raw_pass($cid) eq $pass
+            || $zCap->get_cap_raw_pass( Digest::MD5::md5_base64($pass) ) )
+        and return 0;
     $cap->{raw} = $pass;
+    $cap->{name} =~ tr/\r\n//d;
     $zCap->_plugin( 'zeromin.create.cap', [ $cid, $cap ] );
     $zCap->{__cap_pool}->{$cid} = $cap;
     1;
@@ -140,7 +145,7 @@ sub remove {
     exists $cp->{$cid} and delete $cp->{$cid};
 
     my $iRepos = $zCap->{_repos};
-    my $name   = $iRepos->remove("I:C:I.${cid}.name");
+    my $name = $iRepos->remove("I:C:I.${cid}.name") || '';
     $iRepos->remove("I:C:I.${cid}.raw");
     $iRepos->remove("I:C:I.${cid}.gid");
     $iRepos->remove("I:C:I.${name}.id");
@@ -206,6 +211,15 @@ sub get_caps {
     $ret;
 }
 
+sub get_caps_with_page {
+    my ( $zCap, $unijp, $item_per_page, $offset ) = @_;
+
+    defined $Data::Page::VERSION or require Data::Page;
+    my $entries = $zCap->get_caps($unijp);
+    my $page = Data::Page->new( scalar @$entries, $item_per_page, $offset );
+    return ( [ $page->splice($entries) ], $page );
+}
+
 sub get_cap_pass {
     my ( $zCap, $name ) = @_;
     while ( my ( $cid, $value ) = each %{ $zCap->{__cap_pool} } ) {
@@ -213,7 +227,7 @@ sub get_cap_pass {
     }
 
     my $iRepos = $zCap->{_repos};
-    my $id = $iRepos->get("I:C:I.${name}.id");
+    my $id     = $iRepos->get("I:C:I.${name}.id");
     $id and return $id;
 
     $iRepos->iterate(
@@ -230,6 +244,8 @@ sub get_cap_pass {
     return $id || '';
 }
 
+*get_cap_id = \&get_cap_pass;
+
 sub get_cap_name { shift->_get( 'cap', 'name', @_ ) }
 
 sub get_cap_raw_pass { shift->_get( 'cap', 'raw', @_ ) }
@@ -251,6 +267,7 @@ sub add_group {
         my $iBBS = Img0ch::BBS->new( $iKernel, { id => $scope } );
         $seen->{ $iBBS->get_id() } = 1;
     }
+    $group->{name} =~ tr/\r\n//d;
     $group->{bbs} = [ grep { $_ != 0 } keys %$seen ];
     @{ $group->{bbs} } or @{ $group->{bbs} } = (0);
 
@@ -438,6 +455,15 @@ sub get_groups {
     $ret;
 }
 
+sub get_groups_with_page {
+    my ( $zCap, $item_per_page, $offset ) = @_;
+
+    defined $Data::Page::VERSION or require Data::Page;
+    my $entries = $zCap->get_groups();
+    my $page = Data::Page->new( scalar @$entries, $item_per_page, $offset );
+    return ( [ $page->splice($entries) ], $page );
+}
+
 sub get_group_id {
     my ( $zCap, $name ) = @_;
     while ( my ( $gid, $value ) = each %{ $zCap->{__group_pool} } ) {
@@ -445,7 +471,7 @@ sub get_group_id {
     }
 
     my $iRepos = $zCap->{_repos};
-    my $id = $iRepos->get("I:C:G.${name}.id");
+    my $id     = $iRepos->get("I:C:G.${name}.id");
     $id and return $id;
 
     $iRepos->iterate(
@@ -495,7 +521,26 @@ sub _get {
     else {
         my $prefix = { 'cap' => 'I:C:I', 'group' => 'I:C:G' }->{$type};
         my $iRepos = $zCap->{_repos};
-        $iRepos->get("${prefix}.${id}.${accessor}");
+        my $ret    = $iRepos->get("${prefix}.${id}.${accessor}");
+        if ( !$ret ) {
+            my $new_id;
+            if ( defined $MIME::Base64::VERSION
+                or eval 'require MIME::Base64; 1' )
+            {
+                $new_id
+                    = MIME::Base64::encode_base64( pack( 'H*', $id ), '' );
+            }
+            else {
+                defined $MIME::Base64::Perl::VERSION
+                    or require MIME::Base64::Perl;
+                $new_id
+                    = MIME::Base64::Perl::encode_base64( pack( 'H*', $id ),
+                    '' );
+            }
+            $new_id =~ tr/=//d;
+            $ret = $iRepos->get("${prefix}.${new_id}.${accessor}");
+        }
+        return $ret;
     }
 }
 
