@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Setting.pm 958 2007-08-09 12:26:17Z hikarin $
+# $Id: Setting.pm 1645 2008-02-06 15:40:18Z hikarin $
 #
 
 package Zeromin::Setting;
@@ -230,21 +230,29 @@ sub save {
         my $iKernel = $zSetting->{_kernel};
         my $dir     = $iBBS->get_name();
         $path ||= $zSetting->path();
-        local ( $!, *FH );
-        open *FH, ">${path}"    ## no critic
-            or $iKernel->throw_io_exception($path);
-        print {*FH} $dir, '@', crypt( $dir, $dir ), "\n";
+
+        my $fh = $iKernel->get_write_file_handle($path);
+        print ${fh} $dir, '@', crypt( $dir, $dir ), "\n";
+
+    OUTPUT_DISK:
         for my $key ( @{$keyset} ) {
             my $value    = $cache->{$key};
             my $key_info = $info->{$key};
-            $key_info->{opened} or next;
+            $key_info->{opened} or next OUTPUT_DISK;
             if ( exists $key_info->{except} ) {
-                $key_info->{except} eq $value and next;
+                $key_info->{except} eq $value and next OUTPUT_DISK;
             }
-            print {*FH} $key, '=', $value, "\n"
+            if ( exists $key_info->{condition} ) {
+                my $condition = $key_info->{condition};
+                my ( $ckey, $cval ) = split ':', $condition, 2;
+                my @cvals = split ',', ( $cval || '' );
+                my $cached_value = $cache->{$ckey};
+                map { $cached_value =~ qr/$_/ and next OUTPUT_DISK } @cvals;
+            }
+            print ${fh} $key, '=', $value, "\n"
                 or $iKernel->throw_io_exception($path);
         }
-        close *FH or $iKernel->throw_io_exception($path);
+        close $fh or $iKernel->throw_io_exception($path);
     }
 
     require Zeromin::Plugin;
@@ -259,20 +267,23 @@ sub remove {
 
     %{ $zSetting->{__setting} } = ();
     $zSetting->flush();
-    for my $iRepos ( $zSetting->{_common}, $zSetting->{_system} ) {
-        $iRepos->iterate(
-            sub {
-                my ( $key, $value, $bbs ) = @_;
-                $key =~ /\AI:S\.$bbs\./xms and return -1;
-                return 0;
-            },
-            $zSetting->{_bbs}
-        );
-        $iRepos->save();
-    }
-    unlink $path or $zSetting->{_kernel}->throw_io_exception($path);
 
-    1;
+    my $iRepos = $zSetting->{_common};
+    $iRepos->iterate(
+        sub {
+            my ( $key, $value, $bbs ) = @_;
+            $key =~ /\AI:S\.$bbs\./xms and return -1;
+            return 0;
+        },
+        $zSetting->{_bbs}
+    );
+    $iRepos->save();
+
+    if ( -e $path ) {
+        unlink $path or $zSetting->{_kernel}->throw_io_exception($path);
+    }
+
+    return 1;
 }
 
 1;
