@@ -14,12 +14,13 @@
 # *  limitations under the License.
 # */
 #
-# $Id: cap.pm 900 2007-07-14 14:27:12Z hikarin $
+# $Id: cap.pm 1228 2007-10-01 13:37:14Z hikarin $
 #
 
 package Zeromin2::App::cap;
 
 use strict;
+use Zeromin::Cap qw();
 
 sub load {
     my ($zApp) = @_;
@@ -28,7 +29,7 @@ sub load {
 
     my ( $unijp, $encoding ) = $zApp->unijp();
     return $zApp->return_value( 0,
-        _cap($zApp)->get_caps_with_page( $unijp, $zApp->page_param() ) );
+        _cap($zApp)->get_caps_with_page( $unijp, $zApp->page_param('cap') ) );
 }
 
 sub save {
@@ -39,6 +40,7 @@ sub save {
         or return $zApp->return_value(1);
 
     my $zCap     = _cap($zApp);
+    my $iKernel  = $zApp->kernel();
     my $iRequest = $zApp->request();
     my $error    = {};
     my $param    = {};
@@ -50,7 +52,6 @@ sub save {
     my $name = $param->{name};
     my $pass = $param->{pass};
     my $gid  = $param->{gid};
-    my ( $unijp, $encoding ) = $zApp->unijp();
 
     if ( defined $cap->{id} ) {
         $zApp->privilege('can_edit_cap') or return $zApp->return_value(1);
@@ -64,8 +65,8 @@ sub save {
         $zApp->logger(
             1,
             'EDIT CAP: from %s to %s belongs %d',
-            [   $unijp->set( $cap->{name}, $encoding )->get(),
-                $unijp->set( $name,        $encoding )->get(),
+            [   $iKernel->get_encoded_str( $cap->{name}, 'utf8' ),
+                $iKernel->get_encoded_str( $name,        'utf8' ),
                 $gid
             ],
         );
@@ -84,7 +85,7 @@ sub save {
         $zApp->logger(
             1,
             'CREATE CAP: %s with %s belongs %d',
-            [ $unijp->set( $name, $encoding )->get(), $pass, $gid ],
+            [ $iKernel->get_encoded_str( $name, 'utf8' ), $pass, $gid ],
         );
         $zApp->add_template_param( { Done_cap_create => 1 } );
         $zApp->return_value( 0, $zCap->get_cap_pass($name) );
@@ -147,7 +148,6 @@ sub edit {
 }
 
 sub _cap {
-    require Zeromin::Cap;
     my $zApp = shift;
     my $zCap = Zeromin::Cap->new( $zApp->bbs() || $zApp->kernel() );
     $zCap->load();
@@ -197,13 +197,12 @@ sub _validate_cap_param {
         $param->{pass} = $pass;
     }
 
-    require Unicode::Japanese;
-    my $encoding = $zApp->kernel()->get_config()->get('zeromin2.encoding')
-        || 'utf8';
+    my $iKernel = $zApp->kernel();
     $param->{id}   = $id;
-    $param->{name} = Unicode::Japanese->new( $name, $encoding )->sjis();
+    $param->{name} = $iKernel->get_encoded_str( $name, undef, 'utf8' );
     $param->{gid}  = $group;
-    1;
+
+    return 1;
 }
 
 1;
