@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: filter.pm 1242 2007-10-02 14:06:42Z hikarin $
+# $Id: filter.pm 1635 2008-02-03 13:14:25Z hikarin $
 #
 
 package Zeromin2::App::filter;
@@ -63,12 +63,18 @@ sub load_ngword {
     my $zFNGW
         = Zeromin::Filter::NGWord->new( $zApp->bbs() || $zApp->kernel() );
     $zFNGW->load();
-    return $zApp->return_value(
-        0,
-        $zFNGW->all_in_with_page(
-            $unijp, 0, $zApp->page_param('filter_ngword')
-        )
+    my @data = $zFNGW->all_in_with_page(
+        $unijp, 0, $zApp->page_param('filter_ngword')
     );
+    my $ngwords = $data[0];
+    foreach my $ngword (@$ngwords) {
+        my $apply = $ngword->{apply};
+        $ngword->{"type$ngword->{type}"} = 1;
+        map { $apply & $_ and $ngword->{"apply${_}"} = 1 }
+            qw(1 2 4 8 16);
+    }
+
+    return $zApp->return_value( 0, @data );
 }
 
 sub save_ip {
@@ -178,6 +184,7 @@ sub save_ngword {
     my $meth      = $param->{method};
     my $subs      = $param->{subs};
     my $bbs       = $param->{bbs};
+    my $apply     = $param->{apply};
     my $bbs_name  = $iBBS ? $iBBS->get_name() : '(global)';
     my $word_sjis = $unijp->set( $word, 'utf8' )->sjis();
     my $subs_sjis = $unijp->set( $subs, 'utf8' )->sjis();
@@ -185,7 +192,7 @@ sub save_ngword {
     if ( $ngword->{id} ) {
         $zApp->privilege('can_edit_ngword') or return $zApp->return_value(1);
         $zFNGW->load();
-        $zFNGW->set( $id, $meth, $subs_sjis, $bbs );
+        $zFNGW->set( $id, $meth, $subs_sjis, $bbs_name, $apply );
         $zFNGW->save();
         $zApp->logger(
             1,
@@ -198,7 +205,7 @@ sub save_ngword {
     else {
         $zApp->privilege('can_add_ngword') or return $zApp->return_value(1);
         $zFNGW->load();
-        $zFNGW->add( $word_sjis, $meth, $subs_sjis );
+        $zFNGW->add( $word_sjis, $meth, $subs_sjis, $apply );
         $zFNGW->save();
         $zApp->logger(
             1,
@@ -234,11 +241,15 @@ sub edit_ngword {
     my $ngword = $zFNGW->get( { id => $zApp->request()->param('id') },
         $unijp, $encoding );
 
+    my %applies;
+    my $apply = $ngword->{apply};
+    map { $apply & $_ and $applies{"Apply$_"} = 1 } qw(1 2 4 8 16); 
     $zApp->add_template_param(
         {   Entry                 => $ngword->{entry},
             Id                    => $ngword->{id},
             To                    => $ngword->{to},
-            "Type$ngword->{type}" => 1
+            "Type$ngword->{type}" => 1,
+            %applies,
         }
     );
     return $zApp->return_value(0);
@@ -324,11 +335,15 @@ sub _validate_ngword_param {
     }
 
     my $meth = $iRequest->param_int('type');
+    my @applies = $iRequest->param('apply');
+    my $apply = 0;
+    map { $apply += Img0ch::Kernel::intval($_) } @applies;
     $meth = { '1' => 1, '2' => 2, '4' => 4 }->{$meth} || 1;
     $param->{bbs}    = $iRequest->param_int('bbs');
     $param->{word}   = $word;
     $param->{method} = $meth;
     $param->{subs}   = $iRequest->param('to');
+    $param->{apply}  = $apply;
     1;
 }
 
